@@ -1,4 +1,4 @@
-#![cfg_attr(feature = "nightly", feature(const_fn_trait_bounds))]
+#![cfg_attr(feature = "nightly", feature(const_fn_trait_bound))]
 
 use lock_api::{GetThreadId, RawMutex, RawReentrantMutex};
 
